@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,35 +23,13 @@
  +-------------------------------------------------------------------------+
 */
 
-/* work with both Cacti 1.x and Cacti 0.8.x */
-if (file_exists(__DIR__ . '/../include/cli_check.php')) {
-	require(__DIR__ . '/../include/cli_check.php');
-} elseif (file_exists(__DIR__ . '/../include/global.php')) {
-	/* do NOT run this script through a web browser */
-	if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-		die('<br>This script is only meant to run at the command line.');
-	}
-
-	$no_http_headers = true;
-
-	require(__DIR__ . '/../include/global.php');
-} else {
-	print "FATAL: Can not initialize the Cacti API" . PHP_EOL;
-	exit(1);
-}
+require(__DIR__ . '/../include/cli_check.php');
 
 if ($config['poller_id'] > 1) {
 	print "FATAL: This utility is designed for the main Data Collector only" . PHP_EOL;
 	exit(1);
 }
 
-// For legacy Cacti behavior
-if (!function_exists('cacti_sizeof')) {
-	function cacti_sizeof($object) {
-		return ($object === false || !is_array($object)) ? 0 : sizeof($object);
-	}
-}
-
 if (!function_exists('get_cacti_cli_version')) {
 	function get_cacti_cli_version() {
 		return db_fetch_cell('SELECT cacti FROM version');
@@ -971,7 +949,7 @@ function loadTable($db, &$records) {
 
 function display_version() {
 	if (!defined('COPYRIGHT_YEARS')) {
-		define('COPYRIGHT_YEARS', '2004-2022');
+		define('COPYRIGHT_YEARS', '2004-2023');
 	}
 
 	$version = get_cacti_cli_version();
