@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -145,7 +145,7 @@ function form_actions() {
 		if (get_request_var('drp_action') == '1') { /* delete */
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __('Click \'Continue\' to delete the folling GPRINT Preset(s).') . "</p>
+					<p>" . __('Click \'Continue\' to delete the following GPRINT Preset(s).') . "</p>
 					<div class='itemlist'><ul>$gprint_list</ul></div>
 				</td>
 			</tr>\n";
