@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -518,7 +518,11 @@ function api_plugin_db_table_create($plugin, $table, $data) {
 
 		$sql .= ') ENGINE = ' . $data['type'];
 
-		if (isset($data['row_format']) && db_get_global_variable('innodb_file_format') == 'Barracuda') {
+		if (isset($data['charset'])) {
+			$sql .= ' DEFAULT CHARSET = ' . $data['charset'];
+		}
+
+		if (isset($data['row_format']) && strtolower(db_get_global_variable('innodb_file_format')) == 'barracuda') {
 			$sql .= ' ROW_FORMAT = ' . $data['row_format'];
 		}
 
@@ -535,10 +539,6 @@ function api_plugin_db_table_create($plugin, $table, $data) {
 			if (isset($data['collate'])) {
 				db_execute("ALTER TABLE `$table` COLLATE = " . $data['collate']);
 			}
-
-			if (isset($data['charset'])) {
-				db_execute("ALTER TABLE `$table` CHARSET = " . $data['charset']);
-			}
 		}
 	}
 }
@@ -961,6 +961,10 @@ function api_plugin_movedown($plugin) {
 function api_plugin_register_hook($plugin, $hook, $function, $file, $enable = false) {
 	$status = 0;
 
+	if (!api_plugin_valid_entrypoint($plugin, __FUNCTION__)) {
+		return false;
+	}
+
 	$exists = db_fetch_cell_prepared('SELECT COUNT(*)
 		FROM plugin_hooks
 		WHERE name = ?
@@ -1048,9 +1052,26 @@ function api_plugin_disable_hooks_all($plugin) {
 	api_plugin_replicate_config();
 }
 
+function api_plugin_valid_entrypoint($plugin, $function) {
+	// Check for invalid entrypoint install/upgrade
+	$backtrace = debug_backtrace();
+	if (cacti_sizeof($backtrace)) {
+		if (!preg_match('/(install|upgrade)/i', $backtrace[2]['function'])) {
+			cacti_log(sprintf('WARNING: Plugin \'%s\' is attempting to call \'%s\' improperly in function \'%s\'', $plugin, $function, $backtrace[2]['function']), false, 'PLUGIN');
+			return false;
+		}
+	}
+
+	return true;
+}
+
 function api_plugin_register_realm($plugin, $file, $display, $admin = true) {
 	$files = explode(',', $file);
 
+	if (!api_plugin_valid_entrypoint($plugin, __FUNCTION__)) {
+		return false;
+	}
+
 	$i = 0;
 	$sql_where = '(';
 	foreach($files as $tfile) {
