@@ -1,14 +1,14 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
  | as published by the Free Software Foundation; either version 2          |
  | of the License, or (at your option) any later version.                  |
  |                                                                         |
- | This program is snmpagent in the hope that it will be useful,           |
+ | This program is distributed in the hope that it will be useful,         |
  | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
@@ -291,7 +291,7 @@ function manager_edit() {
 		print "<div class='tabs'><nav><ul role='tablist'>";
 
 		foreach (array_keys($tabs_manager_edit) as $tab_short_name) {
-			if (($id == 0 & $tab_short_name != 'general')){
+			if (($id == 0 && $tab_short_name != 'general')){
 				print "<li class='subTab'><a href='#' " . (($tab_short_name == get_request_var('tab')) ? "class='selected'" : '') . "'>" . $tabs_manager_edit[$tab_short_name] . '</a></li>';
 			}else {
 				print "<li class='subTab'><a " . (($tab_short_name == get_request_var('tab')) ? "class='selected'" : '') .
@@ -483,7 +483,7 @@ function manager_notifications($id, $header_label) {
 								<?php
 								if (cacti_sizeof($mibs)) {
 									foreach ($mibs as $mib) {
-										print "<option value='" . $mib['mib'] . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . $mib['mib'] . '</option>';
+										print "<option value='" . html_escape($mib['mib']) . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . html_escape($mib['mib']) . '</option>';
 									}
 								}
 								?>
@@ -934,7 +934,7 @@ function form_actions(){
 			get_filter_request_var('id');
 			/* ==================================================== */
 
-			$selected_items = unserialize(stripslashes(get_nfilter_request_var('selected_items')));
+			$selected_items = unserialize(stripslashes(get_nfilter_request_var('selected_items')), array('allowed_classes' => false));
 
 			if ($selected_items !== false) {
 				if (get_nfilter_request_var('drp_action') == '1') { // disable
@@ -1035,8 +1035,11 @@ function form_actions(){
 				if (strstr($key, 'chk_')) {
 					/* grep mib and notification name */
 					$row_id = substr($key, 4);
+
 					list($mib, $name) = explode('__', $row_id);
+
 					$list .= '<li>' . html_escape($name) . ' (' . html_escape($mib) .')</li>';
+
 					$selected_items[$mib][$name] = 1;
 				}
 			}
